/*
Plugin Name: Parallax Engine
Plugin URI: http://beeteam368.com/parallaxengine/
Description: Parallax Engine that reacts to the orientation of a smart device. Where no gyroscope or motion detection hardware is available, the position of the cursor is used instead.
Author: BeeTeam368
Author URI: http://beeteam368.com/
Version: 1.0.6
License: Commercial
*/
;(function($){
	'use strict';	
	var DEFAULTS = {
		relativeInput: 			false,
		clipRelativeInput: 		false,
		calibrationThreshold: 	100,
		calibrationDelay: 		500,
		supportDelay: 			500,
		calibrateX: 			false,
		calibrateY: 			true,
		invertX: 				true,
		invertY: 				true,
		limitX: 				false,
		limitY: 				false,
		scalarX: 				10.0,
		scalarY: 				10.0,
		frictionX: 				0.1,
		frictionY: 				0.1,
		originX: 				0.5,
		originY: 				0.5,
	};
	
	$.fn.pe_control_fnc = function(){
		var $this = $(this);		
		
		//build html
		var $contentParallaxHTML = '';
		var $parallax_elems = $('.hidden-item-calc', $this);
		if($parallax_elems.length==0){return;}
		
		$parallax_elems.each(function(index, element) {
            $contentParallaxHTML+=$(this).html();
        });
		$parallax_elems.remove();		
		if($contentParallaxHTML==''){return;}		
		$('<div class="bt-pe-scene"></div>').prependTo($this);
		var $parallax_scene = $('.bt-pe-scene', $this);
		$parallax_scene.append($contentParallaxHTML);
		//build html		
			
		if($parallax_scene.length==0){return;}
		
		var $relativeinput = DEFAULTS.relativeInput;
		var data_relativeinput=$this.attr('data-relativeinput');
		if(typeof data_relativeinput!='undefined' && data_relativeinput=='true'){
			$relativeinput=true;	
		}
		
		var $clipRelativeInput = DEFAULTS.clipRelativeInput;
		var data_cliprelativeinput=$this.attr('data-cliprelativeinput');
		if(typeof data_cliprelativeinput!='undefined' && data_cliprelativeinput=='true'){
			$clipRelativeInput=true;
		}
		
		var $calibrateX = DEFAULTS.calibrateX;
		var data_calibratex=$this.attr('data-calibratex');
		if(typeof data_calibratex!='undefined' && data_calibratex=='true'){
			$calibrateX=true;
		}
		
		var $calibrateY = DEFAULTS.calibrateY;
		var data_calibratey=$this.attr('data-calibratey');
		if(typeof data_calibratey!='undefined' && data_calibratey=='false'){
			$calibrateY=false;
		}
		
		var $invertX = DEFAULTS.invertX;
		var data_invertx=$this.attr('data-invertx');
		if(typeof data_invertx!='undefined' && data_invertx=='false'){
			$invertX=false;
		}
		
		var $invertY = DEFAULTS.invertY;
		var data_inverty=$this.attr('data-inverty');
		if(typeof data_inverty!='undefined' && data_inverty=='false'){
			$invertY=false;
		}
		
		var $limitX = DEFAULTS.limitX;
		var data_limitx=$this.attr('data-limitx');
		if(typeof data_limitx!='undefined' && isNumber(data_limitx)){
			$limitX=Number(data_limitx);
		}
		
		var $limitY = DEFAULTS.limitY;
		var data_limity=$this.attr('data-limity');
		if(typeof data_limity!='undefined' && isNumber(data_limity)){
			$limitY=Number(data_limity);
		}
		
		var $calibrationThreshold = DEFAULTS.calibrationThreshold;
		var data_calibrationthreshold=$this.attr('data-calibrationthreshold');
		if(typeof data_calibrationthreshold!='undefined' && isNumber(data_calibrationthreshold)){
			$calibrationThreshold=Number(data_calibrationthreshold);
		}
		
		var $calibrationDelay = DEFAULTS.calibrationDelay;
		var data_calibrationdelay=$this.attr('data-calibrationdelay');
		if(typeof data_calibrationdelay!='undefined' && isNumber(data_calibrationdelay)){
			$calibrationDelay=Number(data_calibrationdelay);
		}
		
		var $supportDelay = DEFAULTS.supportDelay;
		var data_supportdelay=$this.attr('data-supportdelay');
		if(typeof data_supportdelay!='undefined' && isNumber(data_supportdelay)){
			$supportDelay=Number(data_supportdelay);
		}
		
		var $scalarX = DEFAULTS.scalarX;
		var data_scalarx=$this.attr('data-scalarx');
		if(typeof data_scalarx!='undefined' && isNumber(data_scalarx)){
			$scalarX=Number(data_scalarx);
		}
		
		var $scalarY = DEFAULTS.scalarY;
		var data_scalary=$this.attr('data-scalary');
		if(typeof data_scalary!='undefined' && isNumber(data_scalary)){
			$scalarY=Number(data_scalary);
		}
		
		var $frictionX = DEFAULTS.frictionX;
		var data_frictionx=$this.attr('data-frictionx');
		if(typeof data_frictionx!='undefined' && isNumber(data_frictionx)){
			$frictionX=Number(data_frictionx);
		}
		
		var $frictionY = DEFAULTS.frictionY;
		var data_frictiony=$this.attr('data-frictiony');
		if(typeof data_frictiony!='undefined' && isNumber(data_frictiony)){
			$frictionY=Number(data_frictiony);
		}
		
		var $originX = DEFAULTS.originX;
		var data_originx=$this.attr('data-originx');
		if(typeof data_originx!='undefined' && isNumber(data_originx)){
			$originX=Number(data_originx);
		}
		
		var $originY = DEFAULTS.originY;
		var data_originy=$this.attr('data-originy');
		if(typeof data_originy!='undefined' && isNumber(data_originy)){
			$originY=Number(data_originy);
		}
		
		var new_params = {
			relativeInput: 			$relativeinput,
			clipRelativeInput: 		$clipRelativeInput,
			calibrationThreshold: 	$calibrationThreshold,
			calibrationDelay: 		$calibrationDelay,
			supportDelay: 			$supportDelay,
			calibrateX: 			$calibrateX,
			calibrateY: 			$calibrateY,
			invertX: 				$invertX,
			invertY: 				$invertY,
			limitX: 				$limitX,
			limitY: 				$limitY,
			scalarX: 				$scalarX,
			scalarY: 				$scalarY,
			frictionX: 				$frictionX,
			frictionY: 				$frictionY,
			originX: 				$originX,
			originY: 				$originY,
			
			//custom param
		};
		
		//setup parallax
		$parallax_scene.parallax({
			relativeInput: 			new_params.relativeinput,
			clipRelativeInput: 		new_params.clipRelativeInput,
			calibrationThreshold: 	new_params.calibrationThreshold,
			calibrationDelay: 		new_params.calibrationDelay,
			supportDelay: 			new_params.supportDelay,
			calibrateX: 			new_params.calibrateX,
			calibrateY: 			new_params.calibrateY,
			invertX: 				new_params.invertX,
			invertY: 				new_params.invertY,
			limitX: 				new_params.limitX,
			limitY: 				new_params.limitY,
			scalarX: 				new_params.scalarX,
			scalarY: 				new_params.scalarY,
			frictionX: 				new_params.frictionX,
			frictionY: 				new_params.frictionY,
			originX: 				new_params.originX,
			originY: 				new_params.originY,
		});
		//setup parallax
		
		$('.pe-scroll-down-more', $this).on('click', function(){
			$('html, body').animate({scrollTop:($this.offset().top + $this.outerHeight())}, 1000);			
		});	
		
		if(navigator.userAgent.match(/(Android|iPod|iPhone|iPad|IEMobile|Opera Mini)/)){return;}
		setTimeout(function(){	
			if($('.html5-background-vd', $this).length>0){					
				$('.html5-background-vd', $this).each(function(index, element) {
					$(this).extCallVide();
				});	
			}
			
			if($('.youtube-background-vd', $this).length>0){
				$('.youtube-background-vd', $this).each(function(index, element) {
					$(this).YTPlayer();
				});	
			}
		},368);
	}
	
	$(document).ready(function(e){		
		$('.bt-pe-container[id*="pe_bt_"]').each(function(index, element) {			
			$(this).pe_control_fnc();
		});	
    });
}(jQuery));